@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2015-04-12'; # DATE
-our $VERSION = '1.10'; # VERSION
+our $DATE = '2015-04-25'; # DATE
+our $VERSION = '1.11'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -52,6 +52,10 @@ has log_level => (
         'warning';
     },
 );
+has validate_args => (
+    is=>'rw',
+    default => 1,
+);
 
 my $formats = [qw/text text-simple text-pretty json json-pretty/];
 
@@ -178,6 +182,8 @@ sub hook_before_action {
     # validate arguments using schema from metadata
   VALIDATE_ARGS:
     {
+        last unless $self->validate_args;
+
         # unless we're feeding the arguments to function, don't bother
         # validating arguments
         last unless $r->{action} eq 'call';
@@ -540,7 +546,7 @@ Perinci::CmdLine::Lite - A lightweight Rinci/Riap-based command-line application
 
 =head1 VERSION
 
-This document describes version 1.10 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-04-12.
+This document describes version 1.11 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-04-25.
 
 =head1 SYNOPSIS
 
@@ -693,6 +699,8 @@ LOG_LEVEL=off.
 Set default log level. The default can also be set via
 LOG_LEVEL/TRACE/DEBUG/VERBOSE/QUIET.
 
+=head2 validate_args => bool (default: 1)
+
 =head1 METHODS
 
 All the methods of L<Perinci::CmdLine::Base>, plus:
